#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 esqueleto
version:              3.4.0.1
visibility:           public
id:                   esqueleto-3.4.0.1-9NYwMaQ8CVmISEMMX6Hzff
key:                  esqueleto-3.4.0.1-9NYwMaQ8CVmISEMMX6Hzff
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  ebc5973d8139768123b8f3a43d1706da
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.Internal.PersistentImport
    Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto

import-dirs:          /usr/lib/ghc-8.10.2/site-local/esqueleto-3.4.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/esqueleto-3.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/esqueleto-3.4.0.1
hs-libraries:         HSesqueleto-3.4.0.1-9NYwMaQ8CVmISEMMX6Hzff
depends:
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2
    attoparsec-0.13.2.4-7uGnKXAWXqp2Qn14d3Hl25 base-4.14.1.0
    blaze-html-0.9.1.2-2CxRFZ3pUcb2942dceW5fY bytestring-0.10.10.0
    conduit-1.3.4-LKkovHkWTkK2IXYqvxsWMR containers-0.6.2.1
    monad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
    persistent-2.11.0.2-743j6nHYeNr8Viijc4VTba
    resourcet-1.2.4.2-E1PquPTZKgvLbHxPSs1hvZ
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2 unliftio-0.2.13.1-JOtlO3A7LEuFgyUPYhTSlD
    unordered-containers-0.2.13.0-HeBOjfSts31GSj9apQxnyX

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

